#!/bin/bash

while getopts u:p:a:h:n:f: option
do
case "${option}"
in
u) MYSQL_USER=$OPTARG;;
p) MYSQL_PASS=$OPTARG;;
h) SVIDHOST=$OPTARG;;
n) NAME=$OPTARG;;
f) FOLDER=$OPTARG;;
esac
done

if [ -z "$MYSQL_USER" ]; then
    echo User needed!
    exit 1
fi

if [ -z "$MYSQL_PASS" ]; then
    echo Password needed!
    exit 1
fi

if [ -z "$NAME"  ]; then
    NAME="result"
fi

if [ -z "$FOLDER"  ]; then
    FOLDER="/tmp/"
fi
mkdir -p $FOLDER
query="SELECT 'host_name',
         'host_svid',
         'host_alias',
         'host_address',
         'serviceinstance_name',
         'serviceinstance_svid',
         'service_name',
         'service_svid',
         'check_name',
         'check_svid',
         'check_commandline'
       UNION ALL
       SELECT
         idx_host.label as host_name,
         idx_host.svid as host_svid,
         host.alias as host_alias,
         host.address as host_address,
         idx.label as serviceinstance_name,
         idx.svid as serviceinstance_svid,
         idx_service.label as service_name,
         idx_service.svid as service_svid,
         idx_check.rendered_label as check_name,
         idx_check.__SVID as check_svid,
         idx_check_nagios.command_line as check_commandline

       FROM internal__sv_index AS idx
         LEFT JOIN sv_service_status__svobjects as sss_s on idx.id = sss_s.id
         LEFT JOIN internal__sv_index as idx_host on idx_host.id = sss_s.hostid
         LEFT JOIN internal__sv_index as idx_service on idx_service.id = sss_s.serviceid
         LEFT JOIN sv_service__nagios_references as idx_check_reference on idx_check_reference.id = idx_service.id
         LEFT JOIN sv_command__svobjects as idx_check on idx_check.id = idx_check_reference.check_command
         LEFT JOIN sv_command__nagios as idx_check_nagios on idx_check_nagios.id = idx_check_reference.check_command
         LEFT JOIN sv_host__nagios as host on idx_host.id = host.id";

if [ -z "$SVIDHOST"  ]; then
    timestamp=$(date +%F)
    NAME=$timestamp"_all_Hosts.csv"
    query="$query WHERE idx.type = 'sv_service_status' and idx.archived = 0
                  INTO OUTFILE '/var/lib/mysql-files/$NAME' FIELDS TERMINATED BY ',' LINES TERMINATED BY '\n';"
else
 timestamp=$(date +%F)
 NAME="$timestamp_$NAME.csv"

    query="$query WHERE idx.type = 'sv_service_status' and idx.archived = 0 AND idx_host.svid = '$SVIDHOST'
                 INTO OUTFILE '/var/lib/mysql-files/$NAME' FIELDS TERMINATED BY ',' LINES TERMINATED BY '\n';"
fi

mysql -u $MYSQL_USER -p$MYSQL_PASS -D svdata -e "$query"
cp  /var/lib/mysql-files/$NAME $FOLDER
echo "Pfad zur Datei: " "$FOLDER""$NAME"
rm -f /var/lib/mysql-files/$NAME
